=============
Flask-EasyAPI
=============


.. image:: https://img.shields.io/pypi/v/flask-easyapi.svg
        :target: https://pypi.python.org/pypi/flask-easyapi
        :alt: Package version`

.. image:: https://img.shields.io/pypi/pyversions/flask-easyapi.svg
        :target: https://pypi.python.org/pypi/flask-easyapi
        :alt: Supported python versions

.. image:: https://img.shields.io/travis/com/hXtreme/flask-easyapi.svg
        :target: https://travis-ci.com/hXtreme/flask-easyapi
        :alt: Bulid status

.. image:: https://img.shields.io/github/license/hXtreme/flask-easyapi.svg
        :target: https://github.com/hXtreme/flask-easyapi/blob/master/LICENSE
        :alt: LICENSE

.. image:: https://readthedocs.org/projects/flask-easyapi/badge/?version=latest
        :target: https://flask-easyapi.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/hXtreme/flask-easyapi/shield.svg
        :target: https://pyup.io/repos/github/hXtreme/flask-easyapi/
        :alt: Updates

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/psf/black
        :alt: Code Style - Black



Rest API on Flask made a little too easy.


* Documentation: https://flask-easyapi.readthedocs.io.


Features
--------

Planned
^^^^^^^

* One to one mapping from functions to api endpoints via decorators
* Use type annotations to automatically add type-checks to parameters recieved in the requests to the api.
* Return HTTP error codes and error messages by raising exceptions.
